kanilog
=======

.. image:: https://img.shields.io/pypi/v/kanilog.svg
    :target: https://pypi.python.org/pypi/kanilog
    :alt: Latest PyPI version

.. image:: .png
   :target: 
   :alt: Latest Travis CI build status



Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`kanilog` was written by `fx-kirin <fx.kirin@gmail.com>`_.
